==> ro_dashboard-1.0.0.tar.gz: ro_dashboard/tests/src/Kernel/SiteGuardianReportTest.php <==
<?php

namespace Drupal\ro_dashboard\Tests\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\ro_dashboard\Entity\RoDashboardSite;
use Drupal\ro_dashboard\Service\SiteGuardianService;
use Drupal\ro_dashboard\Service\SiteInfoUpdateService;
use GuzzleHttp\Client;
use GuzzleHttp\Handler\MockHandler;
use GuzzleHttp\HandlerStack;
use GuzzleHttp\Psr7\Response;

/**
 * Tests Multi Site Status Dashboard sites.
 *
 * @group ro_dashboard
 */
class SiteGuardianReportTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node',
    'user',
    'system',
    'filter',
    'field',
    'text',
    'link',
    'datetime',
    'ro_dashboard',
    'options',
    'file',
  ];

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    $this->installEntitySchema('node');
    $this->installEntitySchema('ro_dashboard_site');
    $this->installEntitySchema('user');
    $this->installConfig(['system']);
  }

  /**
   * Tests publication is published.
   *
   * @dataProvider providerTestUpdateSiteApp
   */
  public function testUpdateSiteApp(string $file, string $global_status, string $status_class): void {
    $ro_dashboard_site = RoDashboardSite::create([
      'id' => '7',
      'label' => 'Test site',
      'status' => '1',
      'created' => time(),
      'changed' => time(),
      'site_url' => 'https://testsite.com',
      'sg_token' => 'test_token',
      'sg_status_report' => TRUE,
      'sg_status_report_ignore' => '',
      'sg_module_update_report' => FALSE,
      'sg_module_update_report_ignore' => '',
    ]);
    $ro_dashboard_site->save();

    $expected_response = new Response(200, [], $this->getDummyResponse($file));
    $mock = new MockHandler([$expected_response]);
    $handler_stack = HandlerStack::create($mock);
    $http_client = new Client(['handler' => $handler_stack]);

    $site_guardian_service = new SiteGuardianService(
    $http_client,
    $this->container->get('renderer'),
    $this->container->get('logger.factory')
    );
    $update_service = new SiteInfoUpdateService(
    $site_guardian_service,
    $this->container->get('entity_type.manager'),
    $this->container->get('queue'),
    $this->container->get('logger.factory')
    );
    $updated = $update_service->updateSite($ro_dashboard_site);
    $this->assertTrue($updated);
    $this->assertEquals('10.3.1', $ro_dashboard_site->get('drupal_version')->value);
    $this->assertEquals('8.1.26', $ro_dashboard_site->get('php_version')->value);
    $this->assertEquals($global_status, $ro_dashboard_site->get('global_status')->value);
    $this->assertEquals($status_class, $ro_dashboard_site->get('status_class')->value);
  }

  /**
   * Returns a valid response object.
   *
   * @param string $filename
   *   The filename of the stub to load.
   * @param int $status
   *   The HTTP status code (optional).
   *
   * @return string
   *   The response object.
   */
  private function getDummyResponse(string $filename, int $status = 200): string {
    $module_path = \Drupal::service('module_handler')
      ->getModule('ro_dashboard')
      ->getPath();
    return file_get_contents($module_path . '/tests/src/Stubs/' . $filename);
  }

  /**
   * Provides data for constructor tests.
   */
  public function providerTestUpdateSiteApp() {
    return [
      'all ok' => [
        'file' => 'status.json',
        'global_status' => 'OK',
        'status_class' => 'ok',
      ],
      'warning' => [
        'file' => 'status_warning.json',
        'global_status' => 'STATUS_WARNING',
        'status_class' => 'warning',
      ],
      'error' => [
        'file' => 'status_error.json',
        'global_status' => 'STATUS_ERROR',
        'status_class' => 'error',
      ],
    ];
  }

}

==> ro_dashboard-1.0.2.tar.gz: ro_dashboard/tests/src/Kernel/SiteGuardianReportTest.php <==
<?php

namespace Drupal\ro_dashboard\Tests\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\ro_dashboard\Entity\RoDashboardSite;
use Drupal\ro_dashboard\Service\SiteGuardianService;
use Drupal\ro_dashboard\Service\SiteInfoUpdateService;
use GuzzleHttp\Client;
use GuzzleHttp\Handler\MockHandler;
use GuzzleHttp\HandlerStack;
use GuzzleHttp\Psr7\Response;

/**
 * Tests Multi Site Status Dashboard sites.
 *
 * @group ro_dashboard
 */
class SiteGuardianReportTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node',
    'user',
    'system',
    'filter',
    'field',
    'text',
    'link',
    'datetime',
    'ro_dashboard',
    'options',
    'file',
  ];

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    $this->installEntitySchema('node');
    $this->installEntitySchema('ro_dashboard_site');
    $this->installEntitySchema('user');
    $this->installConfig(['system']);
  }

  /**
   * Tests publication is published.
   *
   * @dataProvider providerTestUpdateSiteApp
   */
  public function testUpdateSiteApp(string $file, string $global_status, string $status_class): void {
    $ro_dashboard_site = RoDashboardSite::create([
      'id' => '7',
      'label' => 'Test site',
      'status' => '1',
      'created' => time(),
      'changed' => time(),
      'site_url' => 'https://testsite.com',
      'sg_token' => 'test_token',
      'sg_status_report' => TRUE,
      'sg_status_report_ignore' => '',
      'sg_module_update_report' => FALSE,
      'sg_module_update_report_ignore' => '',
    ]);
    $ro_dashboard_site->save();

    $expected_response = new Response(200, [], $this->getDummyResponse($file));
    $mock = new MockHandler([$expected_response]);
    $handler_stack = HandlerStack::create($mock);
    $http_client = new Client(['handler' => $handler_stack]);

    $site_guardian_service = new SiteGuardianService(
    $http_client,
    $this->container->get('renderer'),
    $this->container->get('logger.factory')
    );
    $update_service = new SiteInfoUpdateService(
    $site_guardian_service,
    $this->container->get('entity_type.manager'),
    $this->container->get('queue'),
    $this->container->get('logger.factory')
    );
    $updated = $update_service->updateSite($ro_dashboard_site);
    $this->assertTrue($updated);
    $this->assertEquals('10.3.1', $ro_dashboard_site->get('drupal_version')->value);
    $this->assertEquals('8.1.26', $ro_dashboard_site->get('php_version')->value);
    $this->assertEquals($global_status, $ro_dashboard_site->get('global_status')->value);
    $this->assertEquals($status_class, $ro_dashboard_site->get('status_class')->value);
  }

  /**
   * Returns a valid response object.
   *
   * @param string $filename
   *   The filename of the stub to load.
   * @param int $status
   *   The HTTP status code (optional).
   *
   * @return string
   *   The response object.
   */
  private function getDummyResponse(string $filename, int $status = 200): string {
    $module_path = \Drupal::service('module_handler')
      ->getModule('ro_dashboard')
      ->getPath();
    return file_get_contents($module_path . '/tests/src/Stubs/' . $filename);
  }

  /**
   * Provides data for constructor tests.
   */
  public static function providerTestUpdateSiteApp() {
    return [
      'all ok' => [
        'file' => 'status.json',
        'global_status' => 'OK',
        'status_class' => 'ok',
      ],
      'warning' => [
        'file' => 'status_warning.json',
        'global_status' => 'STATUS_WARNING',
        'status_class' => 'warning',
      ],
      'error' => [
        'file' => 'status_error.json',
        'global_status' => 'STATUS_ERROR',
        'status_class' => 'error',
      ],
    ];
  }

}
